=================================================================
watch-ui: autocompiling script for ui files for PySide2 and PyQt5
=================================================================

Installing
==========

watch-ui can be installed via pip as follows:

::

    pip install watch-ui

Using
=====

::

    watch-ui /path/to/project

Author
======

Stanislav Doronin <mugisbrows@gmail.com>

License
=======

watch-ui is distributed under the terms of MIT license, check `LICENSE` file.

Contributing
============

If you'd like to contribute, fork the project, make changes, and send a pull
request. Have a look at the surrounding code and please, make yours look
alike :-)